==> nextcloud-app-mail-1.11.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/nb.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Automatisk påvisning mislyktes. Bruk manuelt oppsett.",
    "Updating account failed: " : "Oppdatering av konto mislyktes:",
    "Creating account failed: " : "Oppretting av konto mislyktes:",
    "Mail" : "E-post",
    "Auto" : "Auto",
    "Name" : "Navn",
    "Mail Address" : "E-postadresse",
    "Password" : "Passord",
    "Manual" : "Manuell",
    "IMAP Settings" : "IMAP-innstillinger",
    "IMAP Host" : "IMAP-server",
    "IMAP Security" : "IMAP-sikkerhet",
    "None" : "Ingen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-port",
    "IMAP User" : "IMAP-bruker",
    "IMAP Password" : "IMAP-passord",
    "SMTP Settings" : "SMTP-innstillinger",
    "SMTP Host" : "SMTP-server",
    "SMTP Security" : "SMTP-sikkerhet",
    "SMTP Port" : "SMTP-port",
    "SMTP User" : "SMTP-bruker",
    "SMTP Password" : "SMTP-passord",
    "Save" : "Lagre",
    "Connect" : "Koble til",
    "Change name" : "Bytt navn",
    "Signature" : "Signatur",
    "Cancel" : "Avbryt",
    "Add mail account" : "Legg til e-postkonto",
    "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
    "Show keyboard shortcuts" : "Vis tastatursnarveier",
    "Select account" : "Velg konto",
    "Subject" : "Emne",
    "Saving draft …" : "Lagrer kladd…",
    "Draft saved" : "Kladd ble lagret",
    "Upload attachment" : "Last opp vedlegg",
    "Add attachment from Files" : "Legg til vedlegg fra Filer",
    "Uploading attachments …" : "Laster opp vedlegg…",
    "Sending …" : "Sender…",
    "Error sending your message" : "Feil ved sending av meldingen din",
    "Go back" : "Gå tilbake",
    "Retry" : "Prøv igjen",
    "Message sent!" : "Melding sendt!",
    "Write another message" : "Skriv en ny melding",
    "Send" : "Send",
    "Choose a file to add as attachment" : "Velg en fil å legge til som vedlegg",
    "Draft: " : "Kladd:",
    "Mark unread" : "Marker som ulest",
    "Mark read" : "Marker som lest",
    "Unselect" : "Velg bort",
    "Select" : "Velg",
    "Report this bug" : "Rapporter denne feilen",
    "Loading messages" : "Henter meldinger",
    "Choose" : "Velg",
    "Favorites" : "Favoritter",
    "Other" : "Annet",
    "Reply" : "Svar",
    "Forward" : "Fremover",
    "Import into calendar" : "Importer til kalender",
    "Download attachment" : "Last ned vedlegg",
    "Save to Files" : "Lagre i Filer",
    "Unnamed" : "Uten navn",
    "Choose a folder to store the attachment in" : "Velg en mappe å lagre vedlegget i",
    "Save all to Files" : "Lagre alle i Filer",
    "Choose a folder to store the attachments in" : "Velg en mappe å lagre vedleggene i",
    "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
    "Move" : "Flytt",
    "New message" : "Ny melding",
    "Settings" : "Innstillinger",
    "Quota" : "Kvote",
    "Saving" : "Lagrer",
    "Remove account" : "Fjern konto",
    "Loading …" : "Laster...",
    "Mark all as read" : "Marker alle som lest",
    "Edit name" : "Rediger navn",
    "Clear cache" : "Tøm hurtiglager",
    "Not found" : "Ikke funnet",
    "Could not load your draft" : "Kunne ikke laste inn denne kladden",
    "Delete" : "Slett",
    "General" : "Generell",
    "User" : "Bruker",
    "Host" : "Server",
    "Port" : "Port",
    "Keyboard shortcut" : "Hurtigtast",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Speed up your Mail experience with these quick shortcuts." : "Arbeid raskere i Mail med disse raske snarveiene",
    "Compose new message" : "Lag ny melding",
    "Newer message" : "Nyere melding",
    "Older message" : "Eldre melding",
    "Toggle star" : "Merk med stjerne",
    "Toggle unread" : "Merk som ulest",
    "Search" : "Søk",
    "Refresh" : "Oppdater",
    "Connect your mail account" : "Koble til din e-postkonto",
    "All" : "Alle",
    "Archive" : "Arkiv",
    "Drafts" : "Kladder",
    "All inboxes" : "Alle innbokser",
    "Inbox" : "Innboks",
    "Junk" : "Søppel",
    "Sent" : "Sendt",
    "Trash" : "Papirkurv",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny melding \nfra {from}","%n nye meldinger \nfra {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det oppstod et problem under lasting av {tag}{name}{endtag}",
    "Could not load your message" : "Kunne ikke laste meldingene dine",
    "Could not load the desired message" : "Kunne ikke laste den ønskede meldingen",
    "Could not load the message" : "Kunne ikke laste meldingen",
    "Error loading message" : "Feil ved innlasting av melding",
    "Forwarding to %s" : "Videresender til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikk her hvis du ikke blir videresendt automatisk innen noen få sekunder.",
    "Redirect" : "Videresend",
    "The link leads to %s" : "Denne lenken leder til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker å besøke den siden, kan du returnere til <a href=\"%s\">E-post</a>.",
    "Continue to %s" : "Fortsett til %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-1.13.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/nb.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Automatisk påvisning mislyktes. Bruk manuelt oppsett.",
    "Updating account failed: " : "Oppdatering av konto mislyktes:",
    "Important" : "Viktig",
    "Work" : "Arbeid",
    "Personal" : "Personlig",
    "Later" : "Senere",
    "Mail" : "E-post",
    "Auto" : "Auto",
    "Name" : "Navn",
    "Mail address" : "E-postadresse",
    "Password" : "Passord",
    "Manual" : "Manuell",
    "IMAP Settings" : "IMAP-innstillinger",
    "IMAP Host" : "IMAP-server",
    "IMAP Security" : "IMAP-sikkerhet",
    "None" : "Ingen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-port",
    "IMAP User" : "IMAP-bruker",
    "IMAP Password" : "IMAP-passord",
    "SMTP Settings" : "SMTP-innstillinger",
    "SMTP Host" : "SMTP-server",
    "SMTP Security" : "SMTP-sikkerhet",
    "SMTP Port" : "SMTP-port",
    "SMTP User" : "SMTP-bruker",
    "SMTP Password" : "SMTP-passord",
    "Connecting" : "Kobler til",
    "Save" : "Lagre",
    "Connect" : "Koble til",
    "Change name" : "Bytt navn",
    "Signature" : "Signatur",
    "Email address" : "E-post adresse",
    "Cancel" : "Avbryt",
    "Add mail account" : "Legg til e-postkonto",
    "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
    "Show keyboard shortcuts" : "Vis tastatursnarveier",
    "Select account" : "Velg konto",
    "Subject" : "Emne",
    "Saving draft …" : "Lagrer kladd…",
    "Draft saved" : "Kladd ble lagret",
    "Upload attachment" : "Last opp vedlegg",
    "Add attachment from Files" : "Legg til vedlegg fra Filer",
    "Enter a date" : "Skriv inn dato",
    "Uploading attachments …" : "Laster opp vedlegg…",
    "Sending …" : "Sender…",
    "Error sending your message" : "Feil ved sending av meldingen din",
    "Go back" : "Gå tilbake",
    "Retry" : "Prøv igjen",
    "Message sent!" : "Melding sendt!",
    "Send" : "Send",
    "Choose a file to add as attachment" : "Velg en fil å legge til som vedlegg",
    "Draft: " : "Kladd:",
    "Unfavorite" : "Fjern favorittmarkering",
    "Favorite" : "Favoritt",
    "Read" : "Les",
    "Unselect" : "Velg bort",
    "Select" : "Velg",
    "Edit tags" : "Rediger merkelapper",
    "Move" : "Flytt",
    "More actions" : "Flere handlinger",
    "Create event" : "Opprettet hendelse",
    "Report this bug" : "Rapporter denne feilen",
    "All day" : "Hele dagen",
    "Create" : "Opprett",
    "Choose" : "Velg",
    "Favorites" : "Favoritter",
    "Other" : "Annet",
    "Reply" : "Svar",
    "Forward" : "Fremover",
    "Import into calendar" : "Importer til kalender",
    "Download attachment" : "Last ned vedlegg",
    "Save to Files" : "Lagre i Filer",
    "Unnamed" : "Uten navn",
    "Choose a folder to store the attachment in" : "Velg en mappe å lagre vedlegget i",
    "Save all to Files" : "Lagre alle i Filer",
    "Choose a folder to store the attachments in" : "Velg en mappe å lagre vedleggene i",
    "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
    "New message" : "Ny melding",
    "Settings" : "Innstillinger",
    "Quota" : "Kvote",
    "Saving" : "Lagrer",
    "Remove account" : "Fjern konto",
    "Loading …" : "Laster...",
    "Mark all as read" : "Marker alle som lest",
    "Edit name" : "Rediger navn",
    "Clear cache" : "Tøm hurtiglager",
    "Delete" : "Slett",
    "Copy to clipboard" : "Kopiert til utklippstavlen",
    "Add" : "Legg til",
    "Disabled" : "Deaktivert",
    "Enabled" : "Aktivert",
    "Custom" : "Egendefinert",
    "Set" : "Sett",
    "Unset" : "Ikke satt",
    "Add tag" : "Legg til merkelapp",
    "Tag already exists" : "Merkelappen finnes allerede",
    "Not found" : "Ikke funnet",
    "Remove" : "Fjern",
    "Reset" : "Tilbakestill",
    "General" : "Generell",
    "User" : "Bruker",
    "Host" : "Server",
    "Port" : "Port",
    "Keyboard shortcut" : "Hurtigtast",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Speed up your Mail experience with these quick shortcuts." : "Arbeid raskere i Mail med disse raske snarveiene",
    "Compose new message" : "Lag ny melding",
    "Newer message" : "Nyere melding",
    "Older message" : "Eldre melding",
    "Toggle star" : "Merk med stjerne",
    "Toggle unread" : "Merk som ulest",
    "Search" : "Søk",
    "Refresh" : "Oppdater",
    "Connect your mail account" : "Koble til din e-postkonto",
    "All" : "Alle",
    "Archive" : "Arkiv",
    "Drafts" : "Kladder",
    "All inboxes" : "Alle innbokser",
    "Inbox" : "Innboks",
    "Junk" : "Søppel",
    "Sent" : "Sendt",
    "Trash" : "Papirkurv",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny melding \nfra {from}","%n nye meldinger \nfra {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Message sent" : "Melding sendt",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det oppstod et problem under lasting av {tag}{name}{endtag}",
    "Could not load your message" : "Kunne ikke laste meldingene dine",
    "Could not load the desired message" : "Kunne ikke laste den ønskede meldingen",
    "Could not load the message" : "Kunne ikke laste meldingen",
    "Error loading message" : "Feil ved innlasting av melding",
    "Forwarding to %s" : "Videresender til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikk her hvis du ikke blir videresendt automatisk innen noen få sekunder.",
    "Redirect" : "Videresend",
    "The link leads to %s" : "Denne lenken leder til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker å besøke den siden, kan du returnere til <a href=\"%s\">E-post</a>.",
    "Continue to %s" : "Fortsett til %s"
},
"nplurals=2; plural=(n != 1);");
